<?php

declare(strict_types=1);

namespace FiloBlu\Refilo\Block\Order\Email\Items;

use DateTime;
use IntlDateFormatter;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\Locale\Resolver;
use Magento\Framework\Locale\ResolverInterface;
use Magento\Framework\Stdlib\DateTime\Intl\DateFormatterFactory;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Sales\Api\Data\OrderItemInterface;
use Magento\Store\Model\ScopeInterface;

/**
 *
 */
class PreorderItem implements ArgumentInterface
{
    /** @var DateFormatterFactory */
    protected $dateFormatter;

    /** @var Resolver */
    protected $resolver;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * @param DateFormatterFactory $dateFormatter
     * @param ResolverInterface $resolver
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        DateFormatterFactory $dateFormatter,
        ResolverInterface $resolver,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->dateFormatter = $dateFormatter;
        $this->resolver = $resolver;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param OrderItemInterface $orderItem
     * @return false|string
     * @throws NoSuchEntityException|\Exception
     */
    public function getShippingDate(OrderItemInterface $orderItem)
    {
        $product = $orderItem->getProduct();

        if($product) {
            return '';
        }

        $locale = $this->scopeConfig->getValue(
            $this->resolver->getDefaultLocalePath(),
            ScopeInterface::SCOPE_STORE,
            $orderItem->getStoreId()
        ) ?? $this->resolver->getDefaultLocale();

        $staticDate = new DateTime($product->getDateShipping());

        return $this->dateFormatter
            ->create($locale, IntlDateFormatter::SHORT, IntlDateFormatter::NONE)
            ->format($staticDate);
    }

    /**
     * @param \Magento\Sales\Api\Data\OrderItemInterface $orderItem
     * @return bool
     */
    public function hasPreorderDate(OrderItemInterface $orderItem): bool
    {
        $product = $orderItem->getProduct();

        if (!$product) {
            return false;
        }

        return ((bool)$product->getIsPreorder()) && $product->getDateShipping();
    }
}


