<?php
declare(strict_types=1);

namespace FiloBlu\Refilo\Plugins\Mview;

use Magento\Framework\Module\Manager;
use Magento\Framework\ObjectManagerInterface;
use Magento\Inventory\Model\ResourceModel\Stock;
use Magento\Inventory\Model\ResourceModel\Stock\Collection;

/**
 *
 */
class View
{
    /**
     * @var Manager
     */
    private $moduleManager;

    /**
     * @var \Magento\Framework\ObjectManagerInterface
     */
    private $objectManager;


    /**
     * @param Manager $moduleManager
     * @param ObjectManagerInterface $objectManager
     */
    public function __construct(Manager $moduleManager, ObjectManagerInterface $objectManager)
    {
        $this->moduleManager = $moduleManager;
        $this->objectManager = $objectManager;
    }

    /**
     * @link \Magento\Framework\Mview\View::getSubscriptions
     * @param $subject
     * @param $result
     * @return array
     */
    public function afterGetSubscriptions($subject, $result)
    {
        // Crea le subscription a runtime per inventory_stock_{stock_id}
        if ($subject->getId() !== 'beehive_stock_bridge') {
            return $result;
        }

        if (!$this->moduleManager->isEnabled('Magento_Inventory')) {
            return $result;
        }

        /** @var Stock $stockCollection */
        $stockCollection = $this->objectManager->create(Collection::class);

        foreach ($stockCollection as $stock) {

            if ((int)$stock->getId() === 1) {
                continue;
            }

            $name = 'inventory_stock_' . $stock->getId();
            $result[$name] = [
                'name'               => $name,
                'column'             => 'sku',
                'subscription_model' => BeehiveStockBridgeSubscriptionModel::class
            ];
        }

        return $result;
    }
}


